{ config, lib, pkgs, ... }:

let
  mkHost = (import ../modules { lib = lib; pkgs = pkgs; }).mkHost;
in mkHost config {
  userName = "alexander";
  hostName = "mashu";
  overlays = [ "nur" "unstable" "simple" "custom" ];
  hardwareImports = [
    "intel"
    "wifi"
    "mobile"
    "surface-pro6"
  ];
  wireless = true;
  wifiInterface = "wlp1s0";
  programImports = [
    "zsh" "git" "mpv" "tmux" "firefox" "gnome-terminal" "gnome" "i18n" "xournalpp" "nextcloud"
    "distributed-build/offload.nix"
  ];
  fileSystems = {
    "/" = {
      device = "/dev/disk/by-label/root";
      fsType = "btrfs";
    };
    "/boot" = {
      device = "/dev/disk/by-label/boot";
      fsType = "vfat";
    };
  };
  swapDevices = [
    {
      device = "/dev/disk/by-label/swap";
    }
  ];
  extraOptions = old: {
    boot = {
      kernelParams = [ "mem_sleep_default=deep" "kernel.nmi_watchdog=0" "vm.dirty_writeback_centisecs=1500" ];
      extraModprobeConfig = ''
      	options i915 enable_fbc=1 enable_rc6=1 modeset=1
      	options snd_hda_intel power_save=1
       	options snd_ac97_codec power_save=1
      	options iwlwifi power_save=Y
        options iwldvm force_cam=N
      '';
      initrd = {
        availableKernelModules = [ "xhci_pci" "nvme" "usbhid" ];
        kernelModules = [ "kvm-intel" ];
      };
    };

    services.gnome.gnome-settings-daemon.enable = true;
    services.logind.extraConfig = ''
      HandlePowerKey=suspend
    '';
    systemd.user.services = {
      gsd-media = {
        description = "GSD media keys handling";
        wantedBy = [ "default.target" ];
        serviceConfig = {
          Type = "simple";
          ExecStart = "${pkgs.gnome.gnome-settings-daemon}/libexec/gsd-media-keys";
          Restart = "always";
        };
      };
      gsd-power = {
        description = "GSD media keys handling";
        wantedBy = [ "default.target" ];
        serviceConfig = {
          Type = "simple";
          ExecStart = "${pkgs.gnome.gnome-settings-daemon}/libexec/gsd-power";
          Restart = "always";
        };
      };
    };
    programs.phosh = {
      enable = true;
      phocConfig = {
        outputs = {
          "eDP-1" = {
             scale = 2;
          };
        };
      };
    };
  };
}
